@@ -18,31 +18,30 @@ use File::Slurp;
 use File::Spec;
 use File::Spec::Unix;
 use GDBM_File;
-use Getopt::Auto 1.9.2;    # Versions less than this not a good idea
+use Getopt::Auto;
 use HTML::EasyTags;
 use IO::File;
 use IO::Handle;
 use List::MoreUtils qw{any};
-use Pod::HtmlEasy 1.1.11;
+use Pod::HtmlEasy (1.01);
 use Pod::Usage;
 use Readonly;
 use Regexp::Common qw{ whitespace };
 use Storable qw( store retrieve );
-use Uniq;
 
-our $VERSION = '1.0';    # Also appears in "=head1 VERSION" in the POD below
+our $VERSION = qv("0.6.7"); # Also appears in "=head1 VERSION" in the POD below
 
 # Static configuration
-Readonly my $DEBUG     => 0;
+Readonly my $debug     => 0;
 Readonly my $DOT       => q{.};
 Readonly my $EMPTY     => q{};
 Readonly my $NL        => qq{\n};
 Readonly my $NUL       => qq{\0};
 Readonly my $FONTSIZE  => 5;
-Readonly my @SUFFIXES  => qw{ \.pm \.pod \.pl };
-Readonly my $TITLE     => q{Perl Documentation};
-Readonly my $USER      => q{root\@localhost};
-Readonly my $CSS_ADDON => qq(dt { margin-top: 1em; });
+Readonly my @suffixes  => qw{ \.pm \.pod \.pl };
+Readonly my $title     => q{Perl Documentation};
+Readonly my $user      => q{root\@localhost};
+Readonly my $css_addon => qq(dt { margin-top: 1em; });
 
 # Variables that may be set from the command line
 my $scratch;
@@ -50,21 +49,18 @@ my $verbose;
 my $outfile;
 
 # Longest first, otherwise alpha
-my @prefixes
-    = reverse uniq sort { length $a <=> length $b or $a cmp $b } @INC;
+my @prefixes = reverse sort { length $a <=> length $b or $a cmp $b } @INC;
 if ( $prefixes[-1] eq $DOT ) { pop @prefixes; }
 
-# Here we try to accommodate multiple paths, such as /usr/lib/perl5/5.10.0 and
+# Here we try to accomodate multiple paths, such as /usr/lib/perl5/5.10.0 and
 # /usr/local/lib/perl5/site_perl/5.10.0
 my @sources;
-foreach (@prefixes) {
-    if ( -d $_ ) { push @sources, $_; }
-}
+foreach ( @prefixes ) { if ( -d $_ ) { push @sources, $_; } }
 
 my $targetdir = q{/usr/local/doc/HTML/Perl};
 my @addpods   = qw{/usr/local/doc/POD};        # Adds on to @INC
 
-if ($DEBUG) {
+if ($debug) {
 
     # To debug in a smaller environment, use these.
     # Note that if you should use something like
@@ -78,8 +74,8 @@ if ($DEBUG) {
 }
 
 # Make a compiled regex.
-Readonly my $PREFIXER => q{\A} . join( q{/|\A}, @prefixes, @addpods ) . q{/};
-Readonly my $PREFIXRE => qr{$PREFIXER}msx;
+Readonly my $prefixer => q{\A} . join( q{/|\A}, @prefixes, @addpods ) . q{/};
+Readonly my $prefixre => qr{$prefixer}mx;
 
 # Persistant hashes that track the state of PODs converted to HTML.
 # %html_track:
@@ -93,9 +89,9 @@ Readonly my $PREFIXRE => qr{$PREFIXER}msx;
 #   key:   tag for the index (Foo::Bar)
 #   value: ARRAY of [ path to the .html file, last mod time of POD ]
 # See insert_latest() for a specific example.
-my ( %HTML_TRACK,     %nopod_track,     %index_track );
+my ( %html_track,     %nopod_track,     %index_track );
 my ( $html_track_ref, $nopod_track_ref, $index_track_ref )
-    = ( \%HTML_TRACK, \%nopod_track, \%index_track );
+    = ( \%html_track, \%nopod_track, \%index_track );
 
 # %pod_convert:
 #   key:   path to the POD file to convert
@@ -105,18 +101,18 @@ my %pod_convert;
 # Files accessed in the course of index generation
 
 # Index tracking and nopod tracking files
-Readonly my $HTML_TRACK  => qq{$targetdir/.html_track};
-Readonly my $INDEX_TRACK => qq{$targetdir/.index_track};
-Readonly my $NOPOD_TRACK => qq{$targetdir/.nopod_track};
+Readonly my $html_track  => qq{$targetdir/.html_track};
+Readonly my $index_track => qq{$targetdir/.index_track};
+Readonly my $nopod_track => qq{$targetdir/.nopod_track};
 
 # Default URL for referenced uninstalled PODs
 Readonly my $CPAN => q{search.cpan.org};
 
 # HTML index for converted PODs
-Readonly my $INDEX_FILE => qq{$targetdir/index.html};
+Readonly my $index_file => qq{$targetdir/index.html};
 
 # Stylesheet for generated HTML
-Readonly my $CSS_FILE => qq{$targetdir/.doc.css};
+Readonly my $css_file => qq{$targetdir/.doc.css};
 
 sub TRUE  { return 1 }
 sub FALSE { return 0 }
@@ -131,14 +127,14 @@ sub error_print {
     exit 1;
 }
 
-sub dumpdb {    ## no critic (ProhibitExcessComplexity)
+sub dumpdb {
 
     if ( defined $scratch ) {
         error_print(q{Can't combine -scratch and -dump!})
             or carp q{print fail};
     }
 
-    print qq{$HTML_TRACK$NL} or carp q{print fail};
+    print qq{$html_track$NL} or carp q{print fail};
     for ( sort keys %{$html_track_ref} ) {
         print qq{  $_ =>$NL    $html_track_ref->{$_}->[0]$NL    },
             scalar localtime $html_track_ref->{$_}->[1], $NL
@@ -146,7 +142,7 @@ sub dumpdb {    ## no critic (ProhibitExcessComplexity)
     }
 
     my @index_refs;
-    print qq{$NL$INDEX_TRACK$NL} or carp q{print fail};
+    print qq{$NL$index_track$NL} or carp q{print fail};
     for ( sort keys %{$index_track_ref} ) {
         print qq{  $_ =>$NL} or carp q{print fail};
         if ( int @{ $index_track_ref->{$_} } > 1 ) {
@@ -159,7 +155,7 @@ sub dumpdb {    ## no critic (ProhibitExcessComplexity)
         }
     }
 
-    print qq{$NL$NL$NOPOD_TRACK$NL} or carp q{print fail};
+    print qq{$NL$NL$nopod_track$NL} or carp q{print fail};
     for ( sort keys %{$nopod_track_ref} ) {
         print qq{  $_ =>$NL    }, scalar localtime $nopod_track_ref->{$_}, $NL
             or carp q{print fail};
@@ -191,29 +187,29 @@ sub do_retrieve {
     if ( defined $scratch ) {    # Hashes are not loaded.
         return;
     }
-    if ( !-e $HTML_TRACK ) {     # Hash files are not found.
+    if ( !-e $html_track ) {     # Hash files are not found.
         return;
     }
 
-    if_verbose(qq{Retrieving $HTML_TRACK$NL});
-    $html_track_ref = retrieve($HTML_TRACK)
-        or error_print(qq{Unable to retrieve $HTML_TRACK - $ERRNO});
+    if_verbose(qq{Retrieving $html_track$NL});
+    $html_track_ref = retrieve($html_track)
+        or error_print(qq{Unable to retrieve $html_track - $!});
 
-    if_verbose(qq{Retrieving $INDEX_TRACK$NL});
-    $index_track_ref = retrieve($INDEX_TRACK)
-        or error_print(qq{Unable to retrieve $INDEX_TRACK - $ERRNO});
+    if_verbose(qq{Retrieving $index_track$NL});
+    $index_track_ref = retrieve($index_track)
+        or error_print(qq{Unable to retrieve $index_track - $!});
 
-    if_verbose(qq{Retrieving $NOPOD_TRACK$NL$NL});
-    $nopod_track_ref = retrieve($NOPOD_TRACK)
-        or error_print(qq{Unable to retrieve $NOPOD_TRACK - $ERRNO});
+    if_verbose(qq{Retrieving $nopod_track$NL$NL});
+    $nopod_track_ref = retrieve($nopod_track)
+        or error_print(qq{Unable to retrieve $nopod_track - $!});
     return;
 }
 
 # Execute the Storable module's store() to save the persistent hashes.
 sub do_store {
-    store( $html_track_ref,  $HTML_TRACK );
-    store( $index_track_ref, $INDEX_TRACK );
-    store( $nopod_track_ref, $NOPOD_TRACK );
+    store( $html_track_ref,  $html_track );
+    store( $index_track_ref, $index_track );
+    store( $nopod_track_ref, $nopod_track );
     return;
 }
 
@@ -269,12 +265,12 @@ sub insert_latest {
 # Subroutines which replace the subs internal to pod2html
 # and associated global variables.
 
-# $html_file:
+# $HTML_file:
 #   the file currently being generated, and is used for
 #   links within the page.
-my $html_file;
+my $HTML_file;
 
-sub on_l {    ## no critic (ProhibitManyArgs)
+sub on_L {
     my ( $this, $text, $inferred, $name, $section, $type ) = @_;
 
     if ( $type eq q{pod} ) {
@@ -315,7 +311,7 @@ sub on_l {    ## no critic (ProhibitManyArgs)
     if ( $type eq q{man} ) {
 
  # $name probably looks like "foo(1)", and the () are interpreted as metachars
-        if ( $inferred !~ m{\Q$name\E}sxm ) { $inferred .= qq{ in $name}; }
+        if ( $inferred !~ m{\Q$name\E}xm ) { $inferred .= qq{ in $name}; }
         return qq{<i>$inferred</i>};
     }
 
@@ -332,19 +328,19 @@ sub on_l {    ## no critic (ProhibitManyArgs)
     return $EMPTY;
 }
 
-my $podhtml = Pod::HtmlEasy->new( on_l => \&on_l, );
+my $podhtml = Pod::HtmlEasy->new( on_L => \&on_L, );
 
 # This a "wanted" sub for File::Find.
 # It accepts files with extension .pod or with extension .pm or .pl and
 # which have a line that begins with "=\w+" and saves them in the
-# HTML_TRACK hash. If they've been modified since last conversion,
+# html_track hash. If they've been modified since last conversion,
 # or never converted, the file is stuffed into the pod_convert hash.
 # If a POD file is removed, it's entry will linger in the persistent files.
 
 sub list_pods {
 
     my $podfile = $File::Find::name;
-    my ( $name, $path, $suffix ) = fileparse( $podfile, @SUFFIXES );
+    my ( $name, $path, $suffix ) = fileparse( $podfile, @suffixes );
 
     if ( length $suffix == 0 ) {
         return;
@@ -373,8 +369,8 @@ sub list_pods {
     if ( defined $track ) {
 
         # We've converted this POD before.
-        my ( $this_htmlfile, $this_ftime ) = @{$track};
-        if ( -e $this_htmlfile and ( $this_ftime >= $podmtime ) ) {
+        my ( $htmlfile, $ftime ) = @{$track};
+        if ( -e $htmlfile and ( $ftime >= $podmtime ) ) {
 
             # The podfile was previously converted and it hasn't
             # been modified since, and the HTML version is still around.
@@ -390,7 +386,7 @@ sub list_pods {
 
         # Get the source and check
         # This is not foolproof.  But its cheap.
-        if ( not any {m{^=\w+}msx} ( read_file($podfile) ) ) {
+        if ( not any {m{^=\w+}mx} ( read_file($podfile) ) ) {
             if_verbose(qq{  no POD$NL});
             $nopod_track_ref->{$podfile} = $podmtime;
             return;
@@ -398,23 +394,22 @@ sub list_pods {
     }
 
     # We have a POD to convert. The time is last-modified of POD.
-    # %HTML_TRACK has the state of the index database.
+    # %html_track has the state of the index database.
     # %pod_convert has the PODs that are to be converted this run.
 
     my $newpath;
-
     # @sources is sorted longest first, so we strip as much as possible.
     # There's a possibility of multiple sources mapping to a single target.
-    foreach my $sourcedir (@sources) {
-        if ( $path =~ m{\A$sourcedir}msx ) {
+    foreach my $sourcedir ( @sources ) {
+        if ( $path =~ m{\A$sourcedir}mx ) {
             $newpath = $path;
-            $newpath =~ s{\A$sourcedir}{$targetdir}msx;
+            $newpath =~ s{\A$sourcedir}{$targetdir}mx;
             last;
         }
     }
 
     if ( not defined $newpath ) {
-        error_print(qq{Unable to strip prefix from $podfile});
+        error_print( qq{Unable to strip prefix from $podfile} );
     }
 
     # Construct a path for the HTML file.
@@ -428,26 +423,26 @@ sub list_pods {
 # Convert a POD file to HTML
 
 sub convert_pod {
-    my ( $local_file, $from_pod_file, $to_html_file ) = @_;
+    my ( $local_file, $pod_file, $html_file ) = @_;
 
     # Make an HTML file from the POD
-    if ( defined $to_html_file ) {
+    if ( defined $html_file ) {
 
-        # $html_file is global as its needed by on_l()
-        $html_file = $to_html_file;
-        my ( $name, $path ) = fileparse($html_file);
+        # $html_file is global as its needed by on_L()
+        $HTML_file = $html_file;
+        my ( $name, $path ) = fileparse($HTML_file);
         if ( !-d $path ) { mkpath($path); }
 
-        print qq{$from_pod_file =>$NL  $html_file$NL} or carp q{podrint};
+        print qq{$pod_file =>$NL  $HTML_file$NL} or carp q{podrint};
     }
 
-    my $pod_name = $from_pod_file;
-    my @pod2args = $from_pod_file;
-    if ( $from_pod_file eq q{-} ) {
-        $pod_name = defined $to_html_file ? $to_html_file : q{STDOUT};
+    my $pod_name = $pod_file;
+    my @pod2args = $pod_file;
+    if ( $pod_file eq q{-} ) {
+        $pod_name = defined $html_file ? $html_file : q{STDOUT};
         push @pod2args, $pod_name;
     }
-    push @pod2args, css => $local_file ? undef : $CSS_FILE;
+    push @pod2args, css => $local_file ? undef : $css_file;
     push @pod2args, index_item => 1;
     push @pod2args, top        => 'uArr';
 
@@ -459,7 +454,7 @@ sub convert_pod {
 
     # This should be near the top of the page
     foreach my $html_line (@html) {
-        $html_line =~ m{<body}msx and do {
+        $html_line =~ m{<body}mx and do {
             $html_line .= $heading;
             last;
         };
@@ -467,15 +462,14 @@ sub convert_pod {
 
     # And this should be near the end of the list.
     foreach my $html_line ( reverse @html ) {
-        $html_line =~ m{</body}msx and do {
+        $html_line =~ m{</body}mx and do {
             $html_line .= $heading;
             last;
         };
     }
 
     # The file has alread been written by pod2html, but that's OK
-    if ( defined $html_file ) { write_file( $html_file, \@html ); }
-
+    if ( defined $HTML_file ) { write_file( $HTML_file, \@html ); }
     return;
 }
 
@@ -492,7 +486,7 @@ sub convert_local {
             next;
         }
 
-        my ( $name, $path, $suffix ) = fileparse( $pod_file, @SUFFIXES );
+        my ( $name, $path, $suffix ) = fileparse( $pod_file, @suffixes );
         $outfile = qq{$name.html};
 
         convert_pod( TRUE, $pod_file, $outfile );
@@ -527,17 +521,17 @@ sub definition {
 
     # The first thing we need to do is to define the 0-level
     my $tag = $tags_ref->[0];
-    my ($section) = $tag->[0][0] =~ m{^(\w+)}sxm;
-    if ( $section =~ m{^perl}msx ) { $section =~ q{perl}; }
+    my ($section) = $tag->[0][0] =~ m{^(\w+)}xm;
+    if ( $section =~ m{^perl}mx ) { $section =~ q{perl}; }
     $index_fh->print( $html->dt($section) );
 
     $index_fh->print( $html->dd_start );
-    while ( my $this_tag = shift @{$tags_ref} ) {
-        my $index = $this_tag->[1];
+    while ( my $tag = shift @{$tags_ref} ) {
+        my $index = $tag->[1];
 
         # Two-step calc preserves single names (no '::")
         my $name = $index;
-        $name =~ s{${section}::}{}sxm;
+        $name =~ s{${section}::}{}xm;
         my $link = $index_track_ref->{$index}[0][0];
         $index_fh->print(
             $html->a(
@@ -558,27 +552,27 @@ Readonly my $NTAG => 3;
 
 sub get_first {
     my $tags_ref = shift;
-    my ($first) = ${$tags_ref}[0] =~ m{^(\w+)}sxm;
+    my ($first) = ${$tags_ref}[0] =~ m{^(\w+)}xm;
     my @first_tags;
 
   # The purpose of $first_re is to cause the Perl pages (perlops, perlre, etc.
   # to sort together
     my $first_re;
-    if   ( $first =~ m{\Aperl}sxm ) { $first_re = qr{\Aperl}sxm; }
-    else                            { $first_re = qr{\A$first\z}sxm; }
+    if   ( $first =~ m{^perl}xm ) { $first_re = qr{^perl}xm; }
+    else                          { $first_re = qr{^$first$}xm; }
     while ( my $tag = shift @{$tags_ref} ) {
-        my ($tagprefix) = $tag =~ m{^(\w+)}sxm;
-        if ( $tagprefix !~ m{$first_re}sxm ) {
+        my ($tagprefix) = $tag =~ m{^(\w+)}xm;
+        if ( $tagprefix !~ m{$first_re}xm ) {
             unshift @{$tags_ref}, $tag;
             return \@first_tags;
         }
-        push @first_tags, [ [ split /::/sxm, $tag, $NTAG ], $tag ];
+        push @first_tags, [ [ split /::/xm, $tag, $NTAG ], $tag ];
     }
     return \@first_tags;
 }
 
 sub key_sort {
-    if ( uc( substr $a, 0, 1 ) ne uc( substr $b, 0, 1 ) ) {
+    if ( uc substr( $a, 0, 1 ) ne uc substr( $b, 0, 1 ) ) {
         return uc $a cmp uc $b;
     }
     return $a cmp $b;
@@ -588,28 +582,28 @@ sub key_sort {
 # the HTML files were changed.
 sub build_index {
 
-    $index_fh = IO::File->new( $INDEX_FILE, '>' )
-        or error_print(qq{Can't open $INDEX_FILE: $ERRNO});
+    $index_fh = new IO::File( $index_file, '>' )
+        or error_print(qq{Can't open $index_file: $!});
     $html = HTML::EasyTags->new();
     $html->groups_by_default(1);
 
     # Do the HTML document header
     $index_fh->print(
         $html->start_html(
-            $TITLE,
+            $title,
             [   $html->link(
                     rel  => q{stylesheet},
-                    href => $CSS_FILE,
+                    href => $css_file,
                     type => q{text/css}
                 ),
                 $html->link(
                     rev  => q{made},
-                    href => qq{mailto:$USER}
+                    href => qq{mailto:$user}
                 ),
             ],
         ),
         $html->font_start( size => $FONTSIZE ),
-        $html->strong( $html->center($TITLE) ),
+        $html->strong( $html->center($title) ),
         $html->font_end,
         $html->hr,    # Horizontal rule
         $html->p,
@@ -632,7 +626,7 @@ sub build_index {
 # Here's where it all begins
 
 # Persistant hashes not updated.
-local $SIG{INT} = sub { exit 1; };
+$SIG{INT} = sub { exit 1; };
 
 # Print it now!
 *STDOUT->autoflush();
@@ -643,20 +637,21 @@ sub outfile {
 }
 
 sub help {
-    pod2usage( -verbose => 2 );
+    pod2usage( -verbose => 2 ); 
     exit 0;
 }
 
-# This is set (magically) by Getopt::Auto
-our %options;    ## no critic (ProhibitPackageVars)
+our %options;
 
-if ( exists $options{'--scratch'} ) {
-    $scratch = 1;
+# See if we've been given an option that we don't recognize
+foreach my $opt ( keys %options ) {
+    if ( not Getopt::Auto::test_option($opt) ) {
+        pod2usage( -verbose => 1 ); 
+    }
 }
 
-if ( exists $options{'--verbose'} ) {
-    $verbose = 1;
-}
+$scratch = 1 if exists $options{'scratch'};
+$verbose = 1 if exists $options{'verbose'};
 
 do_retrieve();
 
@@ -664,11 +659,11 @@ if ( exists $options{'dumpdb'} ) { dumpdb(); exit 0; }
 
 if (@ARGV) { convert_local(); exit 0; }
 
-# Put CSS_ADDON at the end of the css
+# Put css_addon at the end of the css
 # 'x' is inappropriate here
-my @css = split m{$NL}sxm, Pod::HtmlEasy::Data::css;
-push @css, splice @css, -1, 1, $CSS_ADDON; ## no critic (ProhibitMagicNumbers)
-write_file( $CSS_FILE, join( qq{$NL}, @css ) . $NL );
+my @css = split m{$NL}m, Pod::HtmlEasy::Data::css;
+push @css, splice @css, -1, 1, $css_addon;
+write_file( $css_file, join( qq{$NL}, @css ) . $NL );
 
 if ( not -d $targetdir ) {
     mkdir $targetdir
@@ -680,7 +675,7 @@ if ( not -w $targetdir ) {
 }
 
 # Generate a hash (in %pod_convert) of qualifying .pm, .pl and .pod files
-# and keep up-to-date the hash of the HTML file state (%HTML_TRACK)
+# and keep up-to-date the hash of the HTML file state (%html_track)
 
 if_verbose(qq{Indexing .pm, .pl and .pod$NL$NL});
 find( \&list_pods, @sources );
@@ -696,7 +691,7 @@ foreach my $podfile ( values %pod_convert ) {
     my $htmlfile = $html_track_ref->{$podfile};
 
     # "." marks the beginning of the suffix
-    my ($tag) = $podfile =~ m{$PREFIXRE(.*)\.}msx;
+    my ($tag) = $podfile =~ m{$prefixre(.*)\.}mx;
 
     if ( not defined $tag ) {
 
@@ -711,10 +706,10 @@ foreach my $podfile ( values %pod_convert ) {
 
     # PODs in the pod/ directory of the standard distribution are referred
     # to without the pod:: prefix, so let's just dump it.
-    $tag =~ s{^pod/}{}msx;
+    $tag =~ s{^pod/}{}mx;
 
     # Convert the POD path (Foo/Bar) to a POD name (Foo::Bar)
-    $tag =~ s{/}{::}msxg;
+    $tag =~ s{/}{::}mxg;
 
     if_verbose(qq{$podfile =>$NL  $htmlfile->[0]$NL});
 
@@ -740,20 +735,13 @@ __END__
 
 =pod
 
-=begin stopwords
-outfile
-html
-STDIN
-manpage
-=end stopwords
-
 =head1 NAME 
 
 pod2indexed_html - Convert POD files to HTML and create an index page
 
 =head1 VERSION
 
-This documentation refers to pod2indexed_html version 1.0
+This documentation refers to pod2indexed_html version 0.6.7
 
 =head1 SYNOPSIS
 
@@ -780,7 +768,7 @@ of the script to make sure that you like the choices.
 
 =over 4
 
-=item --dump     - Dump F<.html_track>, F<.index_track> and F<.nopod_track>, then exit.
+=item --dump     - Dump .html_track, .index_track and .nopod_track, then exit.
 
 This also provides a list of all links having the same tag.
 
@@ -842,7 +830,7 @@ L<File::Slurp>,
 L<File::Spec>,
 L<File::Spec::Unix>,
 L<GDBM_File>,
-L<Getopt::Auto>,
+L<Getopt::Long>,
 L<HTML::EasyTags>,
 L<IO::File>,
 L<IO::Handle>,
@@ -857,7 +845,7 @@ minor modifications.  Required modules willing, of course.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-The persistent USER environment, configured in the script.
+The persistent user environment, configured in the script.
 
 =over
 
@@ -875,17 +863,17 @@ modules that are mentioned in a POD, but have not been installed locally.
 
 Defaults to the shortest path in @INC.  Usually, that's
 F</usr/lib/perl5>
-If there are multiple roots, we attempt to accommodate that.
+If there are multiple roots, we attempt to accomodate that.
 
 =item $targetdir
 
 Defaults to F</usr/local/doc/HTML/Perl>
 
-=item $USER
+=item $user
 
 Email address for the creator of the index page. Defaults to "root@localhost".
 
-=item $TITLE
+=item $title
 
 Defaults to "Perl Documentation"
 
@@ -910,7 +898,7 @@ would be pointed to by
 F<IPC::Run::Timer>.
 Obviously, this is not going to work very well. The situation is resolved by
 choosing the most recently modified POD file. To see what's going on, run with
--dump and look for the section TITLEd "Multiple index references" at the end.
+-dump and look for the section titled "Multiple index references" at the end.
 
 =item Unable to open F<file> - I<error>
 
@@ -997,6 +985,11 @@ The style sheet that's generated to go with the HTML.
 The source for this file is found in the script,
 at the end of the file.
 
+=item F</usr/local/doc/HTML/Perl/.up.png>
+
+The "back to the top" arrow glyph.
+The source for this file is found in the script.
+
 =back
 
 =head1 INCOMPATIBILITIES
